chrfinder package - Chrfinder 0.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# chrfinder package

## Submodules

## chrfinder.example_module module

Example module to get you started.

chrfinder.example_module.hello_smiles(smiles: str) → str

  Return a greeting string that incorporates the given smiles.

  ### Parameters

  smilesstr

    A text string representing a SMILES (Simplified Molecular Input Line Entry System) notation or any string.

  ### Returns

  str

    A greeting message incorporating the input smiles.

  ### Examples

      >>> hello_smiles("C(=O)O")
      'Hello, C(=O)O!'

## Module contents

The package find the best chromatography based on properties of the mixture.